hello

command
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2026 License: MIT Imports: 1 Imported by: 0

README

hello

An example of how to use mdcode

In this example, the code blocks contain entire files. The test code required for testing is in invisible code blocks.

If you look at the source of this document, you can see how the embedding is done.

JavaScript

console.log("Hello, Testable World!")

go

package main

import "fmt"

func main() {
	fmt.Println("Hello, Testable World!")
}
Tasks

To try mdcode here are some easy tasks

extract

You can extract the example code and the test code using the following command:

mdcode extract
test

After extractiong, you can run the test using the following commands:

go test
node --test
update

After modifying the files, you can update the code blocks in the document using the following command:

mdcode update

Documentation

The Go Gopher

There is no documentation for this package.

Jump to